# -*- Mode: Perl; indent-tabs-mode: nil; -*-

package Bundle::libservlet;

require 5.6;

our $VERSION = '0.9.3';

1;
__END__

=pod

=head1 NAME

Bundle::libservlet - a bundle to install all libservlet related modules

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::libservlet'>

=head1 CONTENTS

Exception::Class

IO::Handle

Servlet

=head1 DESCRIPTION

This bundle includes the libservlet distribution as well as
B<Exception::Class> and B<IO::Handle>.

=head1 AUTHOR

Brian Moseley, bcm@maz.org

=cut
